@@ -1,35 +1,39 @@
 from urllib.parse import urlparse
+
 # local files
 from . import warning
 from .parser import ParsedBadge, BadgeException, FileParser
-from .badge_html import generate_badge_html
+from .badge_html import generate_badge_html, generate_single_element_badge_html
 from .install_badge import InstallBadgeManager
+from .tag_badge import TagBadgeManager
 
 LINK_BADGE_EMPTY_FIELDS = ["copy_text", "link", "reflink"]
 REFLINK_BADGE_EMPTY_FIELDS = LINK_BADGE_EMPTY_FIELDS
 INSTALL_BADGE_EMPTY_FIELDS = LINK_BADGE_EMPTY_FIELDS
 COPY_BADGE_EMPTY_FIELDS = LINK_BADGE_EMPTY_FIELDS
+TAG_BADGE_EMPTY_FIELDS = LINK_BADGE_EMPTY_FIELDS
 STRIP_SUBDOMAINS = [
     "www", # Pretty standard prefix for websites
     "m", # Pretty standard for mobile sites
 ]
 
-def replace_badges(file_name: str, markdown: str, install_badge_manager: InstallBadgeManager) -> str:
+def replace_badges(file_name: str, markdown: str, *args) -> str:
     lines = markdown.split("\n")
     for parser_result_entry in FileParser(file_name, lines).process():
         index = parser_result_entry.line_index
         badge = parser_result_entry.parsed_badge
         try:
-            lines[index] = format_badge(badge, install_badge_manager)
+            lines[index] = format_badge(badge, *args)
         except BadgeException as error:
             warning(f"[{file_name}:{index+1}] Processing error: {error}")
     
     return "\n".join(lines)
 
 
-def format_badge(badge: ParsedBadge, install_badge_manager: InstallBadgeManager) -> str:
+def format_badge(badge: ParsedBadge, install_badge_manager: InstallBadgeManager, tag_badge_manager: TagBadgeManager) -> str:
     badge.check_fields()
     typ = badge.badge_type
+
     if not typ:
         # TODO: Make it possible to use copy_text and reflink at the same time
         if badge.reflink:
@@ -63,6 +67,17 @@ def format_badge(badge: ParsedBadge, install_badge_manager: InstallBadgeManager)
         classes = ["badge-copy", *badge.html_classes]
         return generate_badge_html(badge.title, badge.value, copy_text=badge.value, extra_classes=classes)
 
+    elif typ == "T":
+        badge.assert_all_empty(TAG_BADGE_EMPTY_FIELDS)
+        return tag_badge_manager.format_badge(badge)
+
+    elif typ == "S":
+        classes = ["badge-single", *badge.html_classes]
+        badge_html = generate_single_element_badge_html(badge.title, copy_text=badge.copy_text, link=badge.link, extra_classes=classes)
+        if badge.reflink:
+            badge_html = f"[{badge_html}][{badge.reflink}]"
+        return badge_html
+
     else:
         raise BadgeException(f"Unknown badge type '{typ}'")
 
