@@ -2,7 +2,12 @@ import html
 from typing import Optional
 
 # Invisible separator. Used to make spell checking work correctly and have the copied text be more natural
-SEPARATOR = "<span class=sep> | </span>"
+def as_separator_html(value: str) -> str:
+    return f"<span class=sep>{value}</span>"
+
+START = as_separator_html(" [")
+SEPARATOR = as_separator_html(" | ")
+END = as_separator_html("] ")
 
 
 def generate_badge_html(badge_type: str, badge_value: str, copy_text: Optional[str] = None, link: Optional[str] = None, extra_classes: list[str] = []) -> str:
@@ -24,11 +29,19 @@ def generate_badge_html(badge_type: str, badge_value: str, copy_text: Optional[s
     title_html = element(badge_type, ["title"], copy_text=title_copy)
     value_html = element(badge_value, ["value"], link=value_link)
 
-    inner_html = title_html + SEPARATOR + value_html
+    inner_html = START + title_html + SEPARATOR + value_html + END
     outer_classes = ["badge", *extra_classes]
     return element(inner_html, outer_classes, link=outer_link, copy_text=outer_copy)
 
 
+def generate_single_element_badge_html(badge_type: str, copy_text: Optional[str] = None, link: Optional[str] = None, extra_classes: list[str] = []) -> str:
+    title_html = element(badge_type, ["title"])
+
+    inner_html = START + title_html + END
+    outer_classes = ["badge", *extra_classes]
+    return element(inner_html, outer_classes, link=link, copy_text=copy_text)
+
+
 def element(value: str, class_list: list[str], link: Optional[str] = None, copy_text: Optional[str] = None) -> str:
     if link and copy_text:
         raise Exception("You can not specify both link and copy_text")
